from setuptools import setup

setup(
    name='imagemap',
    version='0.0.0',
    url='https://github.com/njanakiev/imagemap.git',
    author='Author Name',
    author_email='nikolai.janakiev@gmail.com',
    description='imagemap',
    platforms='any',
    packages=['imagemap'],    
    install_requires=[],
)
